@@ -5,23 +5,25 @@ Created on Sat Oct 24 14:34:59 2020
 
 @author: Martín Carlos Araya <martinaraya@gmail.com>
 """
-__version__ = '0.1.2'
-__release__ = 20220831
 
-from .._dictionaries import dictionary
-from .._unit import _units
+__version__ = '0.4.0'
+__release__ = 20220920
+__all__ = ['temperature', 'temperatureGradient']
+
+from ..dictionaries import dictionary
+from ..unit_class import unit
 
 
-class temperature(_units):
+class temperature(unit):
     classUnits = dictionary['temperature']
     def __init__(self, value, units):
         self.name = 'temperature'
         self.kind = temperature
         self.value = self.checkValue(value)
         self.unit = self.checkUnit(units)
-        
 
-class temperatureGradient(_units):
+
+class temperatureGradient(unit):
     classUnits = dictionary['temperatureGradient']
     def __init__(self, value, units):
         self.name = 'temperatureGradient'
